@@ -24,16 +24,19 @@ class Export(object):
     def package(
             self,
             path=None,
+            progress=None,
             cmd='ffmpeg',
             capture_stdout=False,
             capture_stderr=False,
-            input=None):
+            input=None,
+            timeout=None
+         ):
         if path is None:
             self.path = self.filename
         else:
             self.path = path
 
-        return run(self,  cmd, capture_stdout, capture_stderr, input)
+        return run(self, progress, cmd, capture_stdout, capture_stderr, input, timeout)
 
 
 class HLS(Export):
@@ -41,7 +44,9 @@ class HLS(Export):
     def __init__(self, filename, kwargs):
         self.hls_time = kwargs.pop('hls_time', 10)
         self.hls_allow_cache = kwargs.pop('hls_allow_cache', 0)
+        self.strict = kwargs.pop('strict', "-2")
         self.hls_key_info_file = kwargs.pop('hls_key_info_file', None)
+        self.filter = kwargs
         super(HLS, self).__init__(filename)
 
     def encryption(self, url, path, length=16):
@@ -53,6 +58,8 @@ class DASH(Export):
 
     def __init__(self, filename, kwargs):
         self.adaption = kwargs.pop('adaption', None)
+        self.strict = kwargs.pop('strict', "-2")
+        self.filter = kwargs
         super(DASH, self).__init__(filename)
 
 
